@@ -1,9 +1,9 @@
 package Pod::Weaver::Plugin::Sah::Schemas;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-03'; # DATE
+our $DATE = '2020-05-08'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.061'; # VERSION
+our $VERSION = '0.062'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -119,7 +119,7 @@ sub weave_section {
 
 _
 
-                    push @pod, "Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):\n\n";
+                    push @pod, "Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):\n\n";
                     push @pod, <<"_";
  package MyApp;
  our \%SPEC;
@@ -150,12 +150,21 @@ _
                     push @pod, "Sample data:\n\n";
                     for my $eg (@$egs) {
                         # XXX if dump is too long, use Data::Dump instead
-                        push @pod, " ", Data::Dmp::dmp($eg->{data});
+                        my $value = exists $eg->{value} ? $eg->{value} :
+                            $eg->{data};
+                        push @pod, " ", Data::Dmp::dmp($value);
                         if ($eg->{valid}) {
                             push @pod, "  # valid";
-                            push @pod, ", becomes ",
-                                Data::Dmp::dmp($eg->{res})
-                                  if exists $eg->{res};
+                            my $has_validated_value;
+                            my $validated_value;
+                            if (exists $eg->{validated_value}) {
+                                $has_validated_value++; $validated_value = $eg->{validated_value};
+                            } elsif (exists $eg->{res}) {
+                                $has_validated_value++; $validated_value = $eg->{res};
+                            }
+                            if ($has_validated_value) {
+                                push @pod, ", becomes ", Data::Dmp::dmp($validated_value);
+                            }
                         } else {
                             push @pod, "  # INVALID";
                             push @pod, " ($eg->{summary})"
@@ -205,7 +214,7 @@ Pod::Weaver::Plugin::Sah::Schemas - Plugin to use when building Sah::Schemas::*
 
 =head1 VERSION
 
-This document describes version 0.061 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2020-03-03.
+This document describes version 0.062 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
